@@ -22,7 +22,7 @@ class Scraper:
         self.date = None
         self.url = resonpse.url
         self.origin = self.response.origin
-        self._soup = BeautifulSoup(resonpse.text, BS4_SETTING)
+        self._soup = BeautifulSoup(self.resonpse.text, BS4_SETTING)
 
     def getTitle(self):
         """
